@@ -54,6 +54,14 @@ def convert_dict(config: dict, base_path: str):
                 values_to_overwrite = value.get("overwrite")
                 if values_to_overwrite is not None:
                     data = merge(values_to_overwrite, data)
+                for value_to_delete in value.get('delete', list()):
+                    del_path, del_key = str(value_to_delete).rsplit('/',1)
+                    del_base = data
+                    for del_path_elem in del_path.split('/'):
+                        if del_path_elem.strip() != "":
+                            del_base = del_base[del_path_elem]
+                    del del_base[del_key]
+
                 params[key] = {"value": yaml.safe_dump(data)}
             else:
                 logging.warning(
